## Dataloader

- [ ] What args does dataloader have
- [ ] How do the fields relate to the yaml file

## Available dataloaders

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/data.py#L147)</span>
### Dataset

```python
kipoi.data.Dataset()
```

An abstract class representing a Dataset.

All other datasets should subclass it. All subclasses should override
``__len__``, that provides the size of the dataset, and ``__getitem__``,
supporting integer indexing in range from 0 to len(self) exclusive.

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/data.py#L212)</span>
### BatchDataset

```python
kipoi.data.BatchDataset()
```

An abstract class representing a BatchDataset.

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/data.py#L258)</span>
### SampleIterator

```python
kipoi.data.SampleIterator()
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/data.py#L288)</span>
### BatchIterator

```python
kipoi.data.BatchIterator()
```

----

### get_dataloader_factory


```python
get_dataloader_factory(dataloader, source='kipoi')
```

----

### PreloadedDataset


```python
PreloadedDataset(self)
```


Generated by supplying a function returning the full dataset.

The full dataset is a nested (list/dict) python structure of numpy arrays
with the same first axis dimension.

----

### SampleGenerator


```python
SampleGenerator(self)
```


Transform a generator of samples into SampleIterator

----

### BatchGenerator


```python
BatchGenerator(self)
```


Transform a generator of batches into BatchIterator

